@@ -1,4 +1,4 @@
-# Copyright (C) 2018, 2020 Rocky Bernstein <rocky@gnu.org>
+# Copyright (C) 2018, 2020-2021 Rocky Bernstein <rocky@gnu.org>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@
 
 # Things that change more often go here.
 copyright = """
-Copyright (C) 2015-2020 Rocky Bernstein <rb@dustyfeet.com>.
+Copyright (C) 2015-2021 Rocky Bernstein <rb@dustyfeet.com>.
 """
 
 classifiers = [
@@ -43,10 +43,12 @@ classifiers = [
     "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
     "Operating System :: OS Independent",
     "Programming Language :: Python",
+    "Programming Language :: Python :: 2",
     "Programming Language :: Python :: 2.4",
     "Programming Language :: Python :: 2.5",
     "Programming Language :: Python :: 2.6",
     "Programming Language :: Python :: 2.7",
+    "Programming Language :: Python :: 3",
     "Programming Language :: Python :: 3.0",
     "Programming Language :: Python :: 3.1",
     "Programming Language :: Python :: 3.2",
@@ -56,6 +58,9 @@ classifiers = [
     "Programming Language :: Python :: 3.6",
     "Programming Language :: Python :: 3.7",
     "Programming Language :: Python :: 3.8",
+    "Programming Language :: Python :: 3.9",
+    "Programming Language :: Python :: 3.10",
+    "Programming Language :: Python :: Implementation :: PyPy",
     "Topic :: Software Development :: Debuggers",
     "Topic :: Software Development :: Libraries :: Python Modules",
 ]
@@ -70,7 +75,7 @@ entry_points = {
     ]
 }
 ftp_url = None
-install_requires = ["spark-parser >= 1.8.9, < 1.9.0", "xdis >= 5.0.4, <5.1.0"]
+install_requires = ["spark-parser >= 1.8.9, < 1.9.0", "xdis >= 6.0.2, < 6.1.0"]
 
 license = "GPL3"
 mailing_list = "python-debugger@googlegroups.com"
@@ -98,6 +103,6 @@ def read(*rnames):
     return open(os.path.join(srcdir, *rnames)).read()
 
 
-# Get info from files; set: long_description and VERSION
+# Get info from files; set: long_description and __version__
 long_description = read("README.rst") + "\n"
 exec(read("uncompyle6/version.py"))
