@@ -1,4 +1,4 @@
-#  Copyright (c) 2016-2017 by Rocky Bernstein
+#  Copyright (c) 2016-2017, 2021 by Rocky Bernstein
 """
 Python 3.1 bytecode scanner/deparser
 
@@ -16,13 +16,13 @@ from uncompyle6.scanners.scanner3 import Scanner3
 class Scanner31(Scanner3):
 
     def __init__(self, show_asm=None, is_pypy=False):
-        Scanner3.__init__(self, 3.1, show_asm, is_pypy)
+        Scanner3.__init__(self, (3, 1), show_asm, is_pypy)
         return
     pass
 
 if __name__ == "__main__":
     from uncompyle6 import PYTHON_VERSION
-    if PYTHON_VERSION == 3.1:
+    if PYTHON_VERSION == (3, 1):
         import inspect
         co = inspect.currentframe().f_code
         tokens, customize = Scanner31().ingest(co)
