@@ -1,4 +1,4 @@
-#  Copyright (c) 2015-2019 by Rocky Bernstein
+#  Copyright (c) 2015-2019, 2021 by Rocky Bernstein
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ from uncompyle6.scanners.scanner3 import Scanner3
 class Scanner33(Scanner3):
 
     def __init__(self, show_asm=False, is_pypy=False):
-        Scanner3.__init__(self, 3.3, show_asm)
+        Scanner3.__init__(self, (3, 3), show_asm)
         return
     pass
 
